use crate::prelude::*;

use std::os::raw::c_void;
use std::ptr;

#[repr(C)]
#[derive(Debug)]
pub struct VkPhysicalDeviceFeatures2KHR {
    pub sType: VkStructureType,
    pub pNext: *mut c_void,
    pub features: VkPhysicalDeviceFeatures,
}

impl VkPhysicalDeviceFeatures2KHR {
    pub fn new(features: VkPhysicalDeviceFeatures) -> Self {
        VkPhysicalDeviceFeatures2KHR {
            sType: VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_FEATURES_2,
            pNext: ptr::null_mut(),
            features,
        }
    }

    pub fn features(&self) -> VkPhysicalDeviceFeatures {
        self.features
    }
}

impl Default for VkPhysicalDeviceFeatures2KHR {
    fn default() -> Self {
        VkPhysicalDeviceFeatures2KHR::new(VkPhysicalDeviceFeatures::default())
    }
}

impl_pnext_out!(
    VkPhysicalDeviceFeatures2KHR,
    VkPhysicalDeviceDescriptorIndexingFeaturesEXT
);

impl_pnext_out!(
    VkPhysicalDeviceFeatures2KHR,
    VkPhysicalDeviceRayTracingFeaturesKHR
);

impl_pnext_out!(
    VkPhysicalDeviceFeatures2KHR,
    VkPhysicalDeviceBufferDeviceAddressFeaturesEXT
);

impl_pnext_out!(
    VkPhysicalDeviceFeatures2KHR,
    VkPhysicalDeviceAccelerationStructureFeaturesKHR
);
