use crate::prelude::*;

use std::os::raw::c_void;
use std::ptr;

#[repr(C)]
pub struct VkAccelerationStructureVersionInfoKHR {
    pub sType: VkStructureType,
    pub pNext: *const c_void,
    pub versionData: *const u8,
}

impl VkAccelerationStructureVersionInfoKHR {
    pub fn new(version_data: &[u8]) -> Self {
        debug_assert_eq!(
            version_data.len() as u32, 2 * VK_UUID_SIZE,
            "Spec says: versionData must be a valid pointer to an array of 2*VK_UUID_SIZE uint8_t values"
        );

        VkAccelerationStructureVersionInfoKHR {
            sType: VK_STRUCTURE_TYPE_ACCELERATION_STRUCTURE_VERSION_INFO_KHR,
            pNext: ptr::null(),
            versionData: version_data.as_ptr(),
        }
    }
}
